@@ -2,7 +2,7 @@
 /*
  * ggv-window.c: the ggv shell
  *
- * Copyright (C) 2002 the Free Software Foundation
+ * Copyright (C) 2002-2004 the Free Software Foundation
  *
  * Author: Jaka Mocnik  <jaka@gnu.org>
  */
@@ -41,7 +41,7 @@ static GList *window_list = NULL;
 
 /* what can be dragged in us... */
 enum {
-        TARGET_URI_LIST,
+        TARGET_URI_LIST
 };
 
 static void
@@ -728,7 +728,6 @@ ggv_window_destroy(GtkObject *object)
 
         window_list = g_list_remove(window_list, win);
 
-        
         ggv_get_window_size(GTK_WIDGET(object), &w, &h);
         if(w > 1 && h > 1) {
                 ggv_default_width = w;
@@ -910,6 +909,19 @@ open_button_key_pressed_cb (GtkWidget *widget,
                                                                                                                              
         return FALSE;
 }
+static gboolean
+key_press_cb(GtkWidget *widget,
+             GdkEventKey *event,
+             gpointer *data)
+{
+        GgvWindow *win = GGV_WINDOW(widget);
+        if(event->keyval == GDK_Escape && win->fullscreen) {
+                ggv_window_set_fullscreen(win, FALSE);
+                return TRUE;
+        }
+        else
+                return FALSE;
+}
 
 static gboolean
 ggv_file_open_recent (EggRecentView *view, EggRecentItem *item, gpointer data)
@@ -1085,6 +1097,8 @@ ggv_window_new(void)
                                                                                                                              
         g_signal_connect (G_OBJECT (view), "activate",
                           G_CALLBACK (ggv_file_open_recent), win);
+	 g_signal_connect (G_OBJECT (win), "key_press_event",
+                          G_CALLBACK (key_press_cb),NULL);
                                                                                                                              
         if(!win->show_toolbar)
                 bonobo_ui_component_set_prop(uic, "/Toolbar", "hidden", "1", NULL);
